@@ -70,7 +70,7 @@ class random_timeout:
 
 class sleep_for:
     '''Sleep amount of time in minutes, hours or days and prints when it will continue'''
-    def __init__(self, minutes=None, hours=None, days=None):
+    def __init__(self, seconds=None, minutes=None, hours=None, days=None):
         if seconds:
             printr('Sleeping', seconds, 'seconds', level='debug')
             sleep(seconds)
